@@ -74,7 +74,15 @@ class MainWindow(wx.Frame, EventMixin):
 
         self.interfaces = GuiInterfaces(self)
 
-        self._mgr = aui.AuiManager(self)
+        try:
+            self._mgr = aui.AuiManager(self)
+
+        except Exception:
+            # This may fail if py.testv runs under Windows
+            # Therefore, we set up a basic framework for the unit tests
+            self.grid = Grid(self, -1, S=S, dimensions=(1000, 100, 3))
+            self.clipboard = Clipboard()
+            self.actions = AllMainWindowActions(self.grid)
 
         self.parent = parent
 
@@ -650,7 +658,7 @@ class MainWindowEventHandlers(EventMixin):
             _("Pyspread file") + " (*.pys)|*.pys|" + \
             _("All files") + " (*.*)|*.*"
         message = _("Choose pyspread file to open.")
-        style = wx.OPEN | wx.CHANGE_DIR
+        style = wx.OPEN
         filepath, filterindex = \
             self.interfaces.get_filepath_findex_from_user(wildcard, message,
                                                           style)
@@ -718,7 +726,7 @@ class MainWindowEventHandlers(EventMixin):
             _("Pyspread file") + " (*.pys)|*.pys|" + \
             _("All files") + " (*.*)|*.*"
         message = _("Choose filename for saving.")
-        style = wx.SAVE | wx.CHANGE_DIR
+        style = wx.SAVE
         filepath, filterindex = \
             self.interfaces.get_filepath_findex_from_user(wildcard, message,
                                                           style)
@@ -775,7 +783,7 @@ class MainWindowEventHandlers(EventMixin):
             _("CSV file") + " (*.*)|*.*|" + \
             _("Tab delimited text file") + " (*.*)|*.*"
         message = _("Choose file to import.")
-        style = wx.OPEN | wx.CHANGE_DIR
+        style = wx.OPEN
         filepath, filterindex = \
             self.interfaces.get_filepath_findex_from_user(wildcard, message,
                                                           style)
@@ -849,14 +857,14 @@ class MainWindowEventHandlers(EventMixin):
             figure = code_array[cursor]
             if isinstance(figure, Figure):
                 wildcard += \
-                    " |" + _("SVG file") + " (*.svg)|*.svg" + \
-                    " |" + _("EPS file") + " (*.eps)|*.eps" + \
-                    " |" + _("PS file") + " (*.ps)|*.ps" + \
-                    " |" + _("PDF file") + " (*.pdf)|*.pdf" + \
-                    " |" + _("PNG file") + " (*.png)|*.png"
+                    "|" + _("SVG file") + " (*.svg)|*.svg" + \
+                    "|" + _("EPS file") + " (*.eps)|*.eps" + \
+                    "|" + _("PS file") + " (*.ps)|*.ps" + \
+                    "|" + _("PDF file") + " (*.pdf)|*.pdf" + \
+                    "|" + _("PNG file") + " (*.png)|*.png"
 
         message = _("Choose filename for export.")
-        style = wx.OPEN | wx.CHANGE_DIR
+        style = wx.SAVE
         path, filterindex = \
             self.interfaces.get_filepath_findex_from_user(wildcard, message,
                                                           style)
@@ -1150,7 +1158,7 @@ class MainWindowEventHandlers(EventMixin):
             _("All files") + " (*.*)|*.*"
         message = _("Choose macro file.")
 
-        style = wx.OPEN | wx.CHANGE_DIR
+        style = wx.OPEN
         filepath, filterindex = \
             self.interfaces.get_filepath_findex_from_user(wildcard, message,
                                                           style)
@@ -1178,7 +1186,7 @@ class MainWindowEventHandlers(EventMixin):
             _("All files") + " (*.*)|*.*"
         message = _("Choose macro file.")
 
-        style = wx.SAVE | wx.CHANGE_DIR
+        style = wx.SAVE
         filepath, filterindex = \
             self.interfaces.get_filepath_findex_from_user(wildcard, message,
                                                           style)
