@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright 2011 Martin Manns
+# Copyright Martin Manns
 # Distributed under the terms of the GNU General Public License
 
 # --------------------------------------------------------------------
@@ -33,6 +33,10 @@ import os
 import wx
 
 
+# OS
+def is_gtk():
+    return "__WXGTK__" in wx.PlatformInfo
+
 # Paths
 
 
@@ -47,6 +51,19 @@ def get_help_path():
 
     return get_program_path() + "doc/help/"
 
+
+def get_python_tutorial_path():
+    """Returns the Python tutorial path"""
+
+    # If the OS has the Python tutorial installed locally, use it.
+    # the current path is for Debian
+
+    if os.path.isfile("/usr/share/doc/python-doc/html/tutorial/index.html"):
+        return "/usr/share/doc/python-doc/html/tutorial/index.html"
+
+    else:
+        return "http://docs.python.org/2/tutorial/"
+
 # System settings
 
 
@@ -58,9 +75,9 @@ def get_dpi():
 
 
 def get_color(name):
-    """Returns string representation of named system color"""
+    """Returns system color from name"""
 
-    return wx.SystemSettings.GetColour(name).Get()
+    return wx.SystemSettings.GetColour(name)
 
 
 def get_default_font():
@@ -85,4 +102,4 @@ def get_font_list():
     font_list = font_enum.GetFacenames()
     font_list.sort()
 
-    return font_list
\ No newline at end of file
+    return font_list
